<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="aboutui.ui" line="14"/>
        <source>About GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="aboutui.ui" line="74"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Copyright (C) 2009-2014 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Installation ID: $installationId$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright (C) 2009 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;LGPL Crystal Icons by Alvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvUi</name>
    <message>
        <location filename="advui.ui" line="14"/>
        <source>Global Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="20"/>
        <source>Create smart shortened names. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="23"/>
        <source>Synthesize short names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="33"/>
        <source>Convert character set encoding between input and output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="36"/>
        <source>Enable character set transformation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="43"/>
        <source>Preview in Google Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="52"/>
        <source>Debugging diagnostics.  
Higher number provides more deitaled diagnostics.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="57"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="62"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="67"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="72"/>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="77"/>
        <source>3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="82"/>
        <source>4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="87"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="92"/>
        <source>6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="97"/>
        <source>7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="102"/>
        <source>8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="107"/>
        <source>9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="115"/>
        <source>Debugging Diagnostics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="139"/>
        <source>Set all format input/output options to default values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="advui.ui" line="142"/>
        <source>Default Format Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Donate</name>
    <message>
        <location filename="donate.ui" line="32"/>
        <source>Support GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="47"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed) or Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="61"/>
        <source>&lt;p&gt;Of course, if you&apos;ve already contributed  to the project or you just can&apos;t help the project, please check the box below to never see this message again.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="71"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="93"/>
        <source>No, Thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="100"/>
        <source>Contribute</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDlgManager</name>
    <message>
        <location filename="optionsdlg.cc" line="73"/>
        <source>Select input file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdlg.cc" line="77"/>
        <source>Select output file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FilterDialog</name>
    <message>
        <location filename="filterdlg.cc" line="41"/>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="44"/>
        <source>Waypoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="47"/>
        <source>Routes &amp; Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="50"/>
        <source>Miscellaneous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="104"/>
        <source>Are you sure you want to reset all filter options to default values?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FilterDlg</name>
    <message>
        <location filename="filterui.ui" line="14"/>
        <source>Data Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="filterui.ui" line="17"/>
        <source>Data filters process and transform the data between input and output files or devices. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="filterui.ui" line="72"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="filterui.ui" line="83"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GMapDialog</name>
    <message>
        <location filename="gmapdlg.cc" line="55"/>
        <source>meters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="64"/>
        <source>feet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="68"/>
        <source>miles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="71"/>
        <source>Length: %1 %2
  %3 %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="81"/>
        <source>Lat: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="82"/>
        <source>Lng: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="84"/>
        <source>Desc: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="86"/>
        <source>Cmt: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="88"/>
        <source>Ele: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="118"/>
        <source>Start: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="120"/>
        <source>Stop: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="123"/>
        <source>Points: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="150"/>
        <source>Waypoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="165"/>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="180"/>
        <source>Routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="521"/>
        <source>Show All Waypoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="522"/>
        <source>Hide All Waypoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="523"/>
        <location filename="gmapdlg.cc" line="531"/>
        <location filename="gmapdlg.cc" line="539"/>
        <source>Expand All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="524"/>
        <location filename="gmapdlg.cc" line="532"/>
        <location filename="gmapdlg.cc" line="540"/>
        <source>Collapse All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="529"/>
        <source>Show All Routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="530"/>
        <source>Hide All Routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="537"/>
        <source>Show All Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="538"/>
        <source>Hide All Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="545"/>
        <source>Show Only This Waypoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="551"/>
        <source>Show Only This Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="557"/>
        <source>Show Only This Route</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GMapDlg</name>
    <message>
        <location filename="gmapui.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="47"/>
        <source>Copy to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="50"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwinui.ui" line="14"/>
        <source>GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="21"/>
        <source>Input </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="41"/>
        <source>If selected, input is from a file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="44"/>
        <location filename="mainwinui.ui" line="431"/>
        <location filename="mainwinui.ui" line="628"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="57"/>
        <source>If selected, input is from a device or GPS unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="60"/>
        <location filename="mainwinui.ui" line="447"/>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="89"/>
        <location filename="mainwinui.ui" line="476"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="96"/>
        <source>Input data format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="120"/>
        <source>Browse for one or more input files. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="123"/>
        <source>File Name(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="155"/>
        <location filename="mainwinui.ui" line="539"/>
        <source>Device Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="162"/>
        <source>Name of port to which input device is connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="193"/>
        <source>Options for the selected input format. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="196"/>
        <location filename="mainwinui.ui" line="580"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="221"/>
        <source>Translation Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="230"/>
        <location filename="mainwinui.ui" line="273"/>
        <location filename="mainwinui.ui" line="313"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="240"/>
        <source>If selected, translate waypoints.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="243"/>
        <source>Waypoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="280"/>
        <source>If selected, translate routes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="283"/>
        <source>Routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="320"/>
        <source>If selected, translate tracks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="323"/>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="359"/>
        <source>Data Filters between input and output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="362"/>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="395"/>
        <source>More translation options. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="398"/>
        <source>More Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="408"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="428"/>
        <source>If selected, output is to a file. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="444"/>
        <source>If selected, output is to a device or GPS unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="483"/>
        <source>Output data format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="504"/>
        <source>Browse for an output file name. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="507"/>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="546"/>
        <source>Name of port to which output device is connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="577"/>
        <source>Options for the selected output format. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="601"/>
        <source>Output of GPSBabel translation process. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="635"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="651"/>
        <source>GPSBabel Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="656"/>
        <source>About GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="661"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="666"/>
        <source>Preferences...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="671"/>
        <source>Check for Upgrade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="676"/>
        <source>Visit Website...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="681"/>
        <source>Make a Donation...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="528"/>
        <source>Select one or more input files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="555"/>
        <source>Output File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="615"/>
        <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="626"/>
        <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="648"/>
        <source>Input and output formats do not support %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="651"/>
        <source>Input does not support %1; output format supports %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="654"/>
        <source>Input format supports %1; output format does not support %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="657"/>
        <source>Both input and output formats support %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="678"/>
        <source>waypoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="679"/>
        <source>tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="680"/>
        <source>routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="770"/>
        <source>There are no input options for format &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="777"/>
        <location filename="mainwindow.cc" line="797"/>
        <source>Options for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="790"/>
        <source>There are no output options for format &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="811"/>
        <source>No valid waypoints/routes/tracks translation specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="830"/>
        <source>No input file specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="837"/>
        <source>No valid output specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="842"/>
        <source>No output file specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="858"/>
        <source>Process &quot;%1&quot; did not start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="872"/>
        <source>Process exited unsucessfully with code %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1007"/>
        <source>Translation successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1018"/>
        <source>Error running gpsbabel: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1131"/>
        <source>Are you sure you want to reset all format options to default values?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1154"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1197"/>
        <source>One or more data filters are active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1199"/>
        <source>No data filters are active</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Map</name>
    <message>
        <location filename="map.cc" line="66"/>
        <source>Missing &quot;gmapbase.html&quot; file.  Check installation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="map.cc" line="86"/>
        <source>Failed to load Google maps base page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiscFltWidget</name>
    <message>
        <location filename="miscfltui.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="27"/>
        <source>Misc. Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="34"/>
        <source>Nuke (Remove) Data Types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="46"/>
        <location filename="filterwidgets.cc" line="222"/>
        <location filename="filterwidgets.cc" line="223"/>
        <location filename="filterwidgets.cc" line="224"/>
        <location filename="filterwidgets.cc" line="225"/>
        <source>Routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="53"/>
        <location filename="filterwidgets.cc" line="221"/>
        <location filename="filterwidgets.cc" line="222"/>
        <location filename="filterwidgets.cc" line="225"/>
        <location filename="filterwidgets.cc" line="226"/>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="60"/>
        <location filename="filterwidgets.cc" line="221"/>
        <location filename="filterwidgets.cc" line="223"/>
        <location filename="filterwidgets.cc" line="224"/>
        <location filename="filterwidgets.cc" line="226"/>
        <source>Waypoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="72"/>
        <source>Convert routes, waypoints and tracks to different types.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="75"/>
        <source>This filter can be used to convert GPS data between different data types.

Some GPS data formats support only some subset of waypoints, tracks, and routes. The transform filter allows you to convert between these types. For example, it can be used to convert a pile of waypoints (such as those from a CSV file) into a track or vice versa. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="80"/>
        <source>Transform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="87"/>
        <source>Type of transformation. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="94"/>
        <source>Delete original data after transform to prevent duplicated data. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="97"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="119"/>
        <source>Swap Longitude and Latitudes for badly formatted data formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="122"/>
        <source>Simple filter to swap the coordinate values (latitude and longitude) of all points. This can be helpful for wrong defined/coded data. Or if you think, you can use one of our xcsv formats, but latitude and longitude are in opposite order. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="125"/>
        <source>Swap Coordinates</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsDlg</name>
    <message>
        <location filename="optionsdlg.cc" line="192"/>
        <location filename="optionsdlg.cc" line="203"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="preferences.ui" line="20"/>
        <source>GPSBabel Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="30"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="45"/>
        <source>Check for newer version on start.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="52"/>
        <source>Anonymously report usage data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="59"/>
        <source>Ignore mismatch between command line and GUI version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="68"/>
        <source>Formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="76"/>
        <source>Enabled Formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="100"/>
        <source>Enable All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="107"/>
        <source>Disable All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessWaitDialog</name>
    <message>
        <location filename="processwait.cc" line="43"/>
        <source>Process failed to start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="46"/>
        <source>Process crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="49"/>
        <source>Process timedout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="52"/>
        <source>Error while trying to write to process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="55"/>
        <source>Error while trying to read from process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="59"/>
        <source>Unknown process error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="68"/>
        <source> ... Process GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="83"/>
        <source>Stop Process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="155"/>
        <source>Process did not terminate successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="processwait.cc" line="174"/>
        <source>Process crashed whle running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="formatload.cc" line="155"/>
        <source>Error processing formats from running process &quot;gpsbabel -^3&quot; at line %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtTrkWidget</name>
    <message>
        <location filename="rttrkui.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="17"/>
        <source>Simplify routes and tracks by removing points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="20"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The quality of the results will vary depending on the density of points in the original route and the length of the original route. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="40"/>
        <source>Routes &amp; Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="49"/>
        <source>Simplify route by removing points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="52"/>
        <source> The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route.

The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible.

The quality of the results will vary depending on the density of points in the original route and the length of the original route. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="59"/>
        <source>Simplify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="82"/>
        <source>Limit To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="89"/>
        <source>Maximum number points in track or route. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="96"/>
        <source>Points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="118"/>
        <source>Reverse tracks and routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="121"/>
        <source>The reversal is performed in the laziest way possible. Timestamps are kept with the original waypoints so the resulting track or route will have the interesting characteristic that time runs backwards. This tends to make Magellan Mapsend, in particular, do a wierd thing and place each waypoint on a separate day. 
Additionally, if you&apos;re using this to reverse a route that navigates, say, an exit ramp or a one way street, you will be in for unpleasant ride. application cares about timestamps </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="125"/>
        <source>Reverse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackWidget</name>
    <message>
        <location filename="trackui.ui" line="14"/>
        <source>Track Filter Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="17"/>
        <source>This filter performs various operations on track data. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="35"/>
        <source>Track Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="42"/>
        <source>Basic title for track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="45"/>
        <source>Basic title for new track(s). 
This option specifies a title for tracks generated by the track filter. By default, the title of the new track is composed of the start time of the track appended to this value. 
If this value contains a percent (%) character, it is treated as a format string for the POSIX strftime function, allowing custom time-based track names. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="50"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="57"/>
        <source>the title of the new track is composed of the start time of the track appended to this value. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="64"/>
        <source>Correct track point timestamps by specified amount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="67"/>
        <source>Correct trackpoint timestamps by a delta. 
This option changes the time of all trackpoints. This might be useful if your track must be moved by one or more hours because of an incorrect time zone. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="71"/>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="83"/>
        <location filename="trackui.ui" line="275"/>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="97"/>
        <source>hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="111"/>
        <location filename="trackui.ui" line="265"/>
        <source>mins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="125"/>
        <source>secs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="140"/>
        <location filename="trackui.ui" line="155"/>
        <source>Use track pts. after this time. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="143"/>
        <source>Use only track points after this timestamp.

This option is used along with the stop to discard trackpoints that were recorded outside of a specific period of time. This option specifies the beginning of the time period. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="148"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="162"/>
        <source>If checked, time specified here is based on this computer&apos;s current time zone. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="165"/>
        <source>If checked, the times specified here are based on the local computer&apos;s time zone.  Otherwise it is UTC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="168"/>
        <source>Local Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="181"/>
        <location filename="trackui.ui" line="196"/>
        <source>Use track pts before this time. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="184"/>
        <source> Use only track points before this timestamp.

This option is used in conjunction with the start option to discard all trackpoints outside of a given period of time. This option defines the end of the time period. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="189"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="203"/>
        <source>Pack all tracks into one. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="206"/>
        <source>Pack all tracks into one.

This option causes all tracks to be appended to one another to form a single track. This option does not work if any two tracks overlap in time; in that case, consider using the merge option.

This option is most useful for rejoining tracks that might have been interrupted by an equipment malfunction or an overnight stop. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="213"/>
        <source>Pack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="220"/>
        <source>Merge multiple tracks for the same way.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="223"/>
        <source> Merge multiple tracks for the same way.

This option puts all track points from all tracks into a single track and sorts them by time stamp. Points with identical time stamps will be dropped. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="228"/>
        <source>Merge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="235"/>
        <source>Split by Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="242"/>
        <source>Split by Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="254"/>
        <source>If nonzero, the track will be split if the time between two points is greater than this parameter.   If zero, the track will be split by date. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="270"/>
        <source>hrs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="285"/>
        <source>Split by Dist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="297"/>
        <source>If nonzero, the input track will be split into several tracks if the distance between successive track points is greater than the distance given as a parameter. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="308"/>
        <source>ft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="313"/>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="318"/>
        <source>km</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="323"/>
        <source>mi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="341"/>
        <source>GPS Fixes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="349"/>
        <source>none</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="354"/>
        <source>pps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="359"/>
        <source>dgps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="364"/>
        <source>3d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="369"/>
        <source>2d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="392"/>
        <source>Synthesize speed. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="395"/>
        <source>Synthesize speed.

This option computes a value for the GPS speed at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support speed information or for trackoints synthesized by the interpolate filter. The speed at each trackpoint is the average speed from the previous trackpoint (distance divided by time). The first trackpoint in each track is assigned a speed of &quot;unknown.&quot; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="400"/>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="407"/>
        <source>Synthesize course.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="410"/>
        <source>Synthesize course.

This option computes (or recomputes) a value for the GPS heading at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support heading information or for trackpoints synthesized by the interpolate filter. The heading at each trackpoint is simply the course from the previous trackpoint in the track. The first trackpoint in each track is arbitrarily assigned a heading of 0 degrees. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="415"/>
        <source>Course</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Upgrade</name>
    <message>
        <location filename="upgrade.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpgradeCheck</name>
    <message>
        <location filename="upgrade.cc" line="226"/>
        <location filename="upgrade.cc" line="230"/>
        <location filename="upgrade.cc" line="264"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="227"/>
        <source>Unexpected reply.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="231"/>
        <source>Download failed: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="265"/>
        <source>Download failed: %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="281"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="282"/>
        <source>Invalid return data at line %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="328"/>
        <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="339"/>
        <source>Upgrade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="346"/>
        <source>Do you wish to download an upgrade?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionMismatch</name>
    <message>
        <location filename="version_mismatch.ui" line="32"/>
        <source>GPSBabel Version Mismatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="38"/>
        <source>&lt;b&gt;A version mismatch has been detected.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="47"/>
        <source>GPSBabel command line version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="81"/>
        <source>GPSBabel GUI version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="115"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WayPtsWidget</name>
    <message>
        <location filename="wayptsui.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="29"/>
        <source>Waypoints Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="36"/>
        <source>Remove duplicates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="39"/>
        <source>The duplicate filter is designed to remove duplicate points based on their short name (traditionally a waypoint&apos;s name on the GPS receiver), and/or their location (to a precision of 6 decimals). This filter supports two options that specify how duplicates will be recognized, shortname and location. Generally, at least one of these options is required. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="42"/>
        <source>Duplicates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="55"/>
        <source>Suppress duplicate waypoints based on name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="58"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoints based on name. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option is the one most often used with the duplicate filter. This option instructs the duplicate filter to remove any waypoints that share a short name with a waypoint that has come before. This option might be used to remove duplicates if you are merging two datasets that were each created in part from a common ancestor dataset. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="66"/>
        <source>Short Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="73"/>
        <source>Suppress duplicate waypoint based on coords. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="76"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoint based on coords. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option causes the duplicate filter to remove any additional waypoint that has the same coordinates (to six decimal degrees) as a waypoint that came before. This option may be used to remove duplicate waypoints if the names are not expected to be the same. It also might be used along with the &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;shortname&lt;/span&gt; option to remove duplicate waypoints if the names of several unrelated groups of waypoints might be the same. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="84"/>
        <source>Locations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="91"/>
        <source>Remove points based on proximity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="94"/>
        <source>Maximum positional distance.

This option specifies the minimum allowable distance between two points. If two points are closer than this distance, only one of them is kept. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="99"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="112"/>
        <source>Maximum positional distance.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="120"/>
        <source>Feet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="125"/>
        <source>Meters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="133"/>
        <source>Include points only within radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="136"/>
        <source>This filter includes or excludes waypoints based on their proximity to a central point. All waypoints more than the specified distance from the specified point will be removed from the dataset.

By default, all remaining points are sorted so that points closer to the center appear earlier in the output file. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="141"/>
        <source>Radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="154"/>
        <source>Maximum distance from center. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="162"/>
        <source>Miles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="167"/>
        <source>km</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="175"/>
        <source>Lat.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="188"/>
        <source>Latitude of the central point in decimal degrees.  South latitudes should be expressed as a negative number.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="195"/>
        <source>Long.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="208"/>
        <source>Longitude of the central point in decimal degrees. West longitudes should be expressed as a negative number.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="215"/>
        <location filename="wayptsui.ui" line="218"/>
        <source>This filter sorts waypoints into alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="221"/>
        <source>Sort</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
